summaryrefslogtreecommitdiffstats
path: root/kdat/FormatOptDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/FormatOptDlg.h')
-rw-r--r--kdat/FormatOptDlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/FormatOptDlg.h b/kdat/FormatOptDlg.h
index 861fa93..db557e9 100644
--- a/kdat/FormatOptDlg.h
+++ b/kdat/FormatOptDlg.h
@@ -30,6 +30,7 @@ class TQLineEdit;
*/
class FormatOptDlg : public TQDialog {
Q_OBJECT
+ TQ_OBJECT
TQString _name;
int _size;
TQLineEdit* _entry;
@@ -42,10 +43,10 @@ public:
* Create a new format options dialog.
*
* @param def The default value for the tape name.
* @param parent The parent widget for the dialog.
* @param name The name for the dialog.
*/
- FormatOptDlg( const TQString & def, TQWidget* parent=0, const char* name=0 );
+ FormatOptDlg( const TQString & def, TQWidget* tqparent=0, const char* name=0 );
/**
* Destroy the format options dialog.
@@ -42,10 +43,10 @@ public:
*
* @param def The default value for the tape name.
- * @param parent The parent widget for the dialog.
+ * @param tqparent The tqparent widget for the dialog.
* @param name The name for the dialog.
*/